@@ -27,17 +27,26 @@
 #'  and have the function merge this together with the \code{...} argument.
 #'  \emph{Note} that all elements myst have the same \code{by} argument or you
 #'  will not be able to merge it into a list.
+#' @param htmlTable_args Any arguments that should be passed to
+#'  \code{\link[htmlTable]{htmlTable}} function. The default is to remove
+#'  any css formatting for the rgroup.
 #' @return \code{matrix} Returns a matrix object of class descList
 #' @export
 #' @example inst/examples/getDescriptionStatsBy_example.R
 #' @family table functions
-mergeDesc <- function(...){
+mergeDesc <- function(..., htmlTable_args = list(css.rgroup = "")){
   tlist <- list()
   dots <- list(...)
   if (length(dots) > 0){
-    for (add_lst in dots){
-      if (!is.list(add_lst))
+    for (i in 1:length(dots)){
+      add_lst <- dots[[i]]
+      if (!is.list(add_lst)){
         add_lst <- list(add_lst)
+        if (!is.null(names(dots)) &&
+              names(dots)[i] != "")
+          names(add_lst) <- names(dots)[i]
+      }
+
       tlist <- append(tlist,
                       add_lst)
     }
@@ -45,6 +54,7 @@ mergeDesc <- function(...){
 
   mx <- NULL
   rgroup <- n.rgroup <- c()
+  pvals_rgroup <- list()
   for(i in 1:length(tlist)){
     n <- names(tlist)[i]
     if (is.null(n) || n == ""){
@@ -62,6 +72,15 @@ mergeDesc <- function(...){
     if (nrow(tlist[[i]]) > 1){
       rgname <- n
       rgno <- nrow(tlist[[i]])
+      if (tolower(tail(colnames(mx), 1)) == "p-value"){
+        pval <- list(mx[nrow(mx) - nrow(tlist[[i]]) + 1,
+                        ncol(mx)])
+        mx[nrow(mx) - nrow(tlist[[i]]) + 1,
+           ncol(mx)] <- ""
+        names(pval)[1] <- as.character(i)
+        pvals_rgroup <- c(pvals_rgroup,
+                          pval)
+      }
     }else{
       rownames(mx)[NROW(mx)] <- n
       rgname <- ""
@@ -90,12 +109,26 @@ mergeDesc <- function(...){
       }
     }
   }
+  if (length(pvals_rgroup) > 0){
+    attr(rgroup, "add") <- pvals_rgroup
+  }
 
   colnames(mx) <- colnames(tlist[[1]])
 
+  if (rgroup %in% names(htmlTable_args) ||
+        n.rgroup %in% names(htmlTable_args))
+    stop("You have provided rgroup elements within",
+         " htmlTable_args argument and these will conflict",
+         " with the autogenerated rgroups.")
+  if (is.null(names(htmlTable_args)))
+    stop("The htmlTable_args has to be a list or a vector with named elements")
+  if (!is.list(htmlTable_args))
+    htmlTable_args <- as.list(htmlTable_args)
+
   return(structure(mx,
                    rgroup = rgroup,
                    n.rgroup = n.rgroup,
+                   htmlTable_args = htmlTable_args,
                    class = c("descMrg", class(mx))))
 }
 
@@ -130,16 +163,47 @@ latex.descMrg <- function(x, ...)
 #' @rdname htmlTable_latex
 #' @export
 #' @import htmlTable
+#' @import magrittr
 htmlTable.descMrg <- function(x, ...)
 {
   dots <- list(...)
-  if (!"rgroup" %in% names(dots)){
-    return(NextMethod(generic = NULL, object = x,
-                      rgroup = attr(x, "rgroup"),
-                      n.rgroup = attr(x, "n.rgroup"),
-                      ...))
+  htmlTable_args <- attr(x, "htmlTable_args")
+  for (n in names(htmlTable_args)){
+    if (!n %in% names(dots)){
+      dots[[n]] <- htmlTable_args[[n]]
+    }
   }
 
-  return(NextMethod(generic = NULL, object = x,
-                    ...))
+  # Merge calls
+  class(x) <- class(x)[class(x) != "descMrg"]
+  args <- c(list(x = x),
+            dots)
+  if (!"rgroup" %in% names(args)){
+    args[["rgroup"]] <- attr(x, "rgroup")
+    args[["n.rgroup"]] <- attr(x, "n.rgroup")
+  }
+
+  fastDoCall(htmlTable, args)
+}
+
+
+#' @rdname htmlTable_latex
+#' @export
+#' @import htmlTable
+print.descMrg <- function(x, ...)
+{
+  htmlTable(x, ...) %>%
+    print
+}
+
+
+#' @rdname htmlTable_latex
+#' @import htmlTable
+#' @export
+#' @importFrom knitr asis_output
+#' @importFrom knitr knit_print
+knit_print.descMrg <- function(x, ...)
+{
+  htmlTable(x, ...) %>%
+    knit_print
 }
\ No newline at end of file
