@@ -47,8 +47,8 @@ prTpPlotBox <- function(bx, bx_txt, fill, txt_clr,
 
     if (bx_txt != ""){
       bx_grob <- prTpGetBoxSizedTextGrob(txt=bx_txt,
-                                     txt_clr = txt_clr,
-                                     txt_cex = cex)
+                                         txt_clr = txt_clr,
+                                         txt_cex = cex)
       if (!is.null(bx_grob))
         grid.draw(bx_grob)
     }
@@ -192,7 +192,13 @@ prTpPlotArrows <- function(type,
                                       box_width=box_width)
 
       # Calculate line width
-      lwd <- min_lwd + (max_lwd-min_lwd)*transition_flow[box_row,flow]/max_flow
+      lwd <- max_lwd*transition_flow[box_row,flow]/max_flow
+      if (lwd < min_lwd){
+        message("The minimum width reached and the arrow at box no. '", box_row, "' to no. '", flow, "'",
+                " will not be shown. This is due to the fact that the lwd will generate a falsely strong arrow.")
+        next;
+      }
+
       adjusted_lwd <- lwd
       if (is.na(add_width) == FALSE){
         if ("unit" %in% class(add_width)){
@@ -234,7 +240,7 @@ prTpPlotArrows <- function(type,
         x_ctrl_points[4] <- x_ctrl_points[4]-.00075*adjusted_lwd
         grid.bezier(x=x_ctrl_points,
                     y=y_ctrl_points,
-                    gp=gpar(lwd=adjusted_lwd, fill=current_arrow_clr),
+                    gp=gpar(lwd=adjusted_lwd, fill=current_arrow_clr, col=current_arrow_clr),
                     arrow=arrow(type="closed", angle=a_angle, length=unit(a_l, "npc")))
 
       }else{
@@ -294,9 +300,9 @@ prTpPlotArrows <- function(type,
                                     arrow=list(length=a_l, base=a_width),
                                     clr=current_arrow_clr,
                                     grdt_type = "triangle",
+                                    grdt_prop = .8,
                                     grdt_clr_prop = 0.5,
-                                    grdt_start_prop = .3,
-                                    grdt_decrease_prop = .3,
+                                    grdt_decrease_prop = .5,
                                     grdt_clr = current_grdt_clr)
           grid.draw(bz)
 
@@ -574,15 +580,15 @@ prTpGetBoxPositions <- function (no, side,
 #'  at the low/high proportions of the spectrum then it
 #'  can be of interest to focus the color change to the center
 #'  leaving the tails constant
+#' @param The color resolution to use
 #' @return \code{character} The function can return both single colors
 #'  or multiple colors as character vector (see \code{\link[grDevices]{rgb}})
 #'
 #' @keywords internal
-prTpGetColors <- function(colors, proportion, space){
+prTpGetColors <- function(colors, proportion, space = NULL, no = 101){
   start <- c()
   end <- c()
-  no <- 101
-  if (!missing(space)){
+  if (!is.null(space)){
     if(any(space > 1 | space < 0))
       stop("Your color subspace that you define should be between 0 and 1")
 
@@ -596,7 +602,7 @@ prTpGetColors <- function(colors, proportion, space){
       end_no <- ceiling(space[2]*no)
       start <- rep(colors[1], times=start_no)
       end <- rep(tail(colors, 1), times=end_no)
-      no <- no - start_no - end_no
+      no <- end_no - start_no
       if (no < 0)
         no <- 0
     }else{
